@@ -1,4 +1,4 @@
-pub trait Command: Send + Sync {
+pub trait Command: Send + Sync + Clone {
   fn name(&self) -> &'static str;
   fn aggregate_id(&self) -> &str;
 }
