@@ -2,7 +2,7 @@ use serde::{Deserialize, Serialize};
 
 use crate::Version;
 
-pub trait Event: Send + Sync {
+pub trait Event: Send + Sync + Clone {
   fn name(&self) -> &'static str;
 }
 
@@ -11,7 +11,7 @@ pub struct PersistedEvent<T>
 where
   T: Event,
 {
-  pub stream_id: String,
+  pub aggregate_id: String,
   pub version: Version,
   pub event: T,
 }
